@@ -1,10 +1,12 @@
 import inspect
 import functools
+import warnings
 
 import uuid
 import marshmallow as ma
 from marshmallow import validate, fields
 from sqlalchemy.dialects import postgresql, mysql, mssql
+from sqlalchemy.orm import SynonymProperty
 import sqlalchemy as sa
 
 from .exceptions import ModelConversionError
@@ -79,6 +81,7 @@ class ModelConverter:
         model,
         *,
         include_fk=False,
+        include_relationships=False,
         fields=None,
         exclude=None,
         base_fields=None,
@@ -87,9 +90,12 @@ class ModelConverter:
         result = dict_cls()
         base_fields = base_fields or {}
         for prop in model.__mapper__.iterate_properties:
+            key = self._get_field_name(prop)
             if self._should_exclude_field(prop, fields=fields, exclude=exclude):
                 # Allow marshmallow to validate and exclude the field key.
-                result[prop.key] = None
+                result[key] = None
+                continue
+            if isinstance(prop, SynonymProperty):
                 continue
             if hasattr(prop, "columns"):
                 if not include_fk:
@@ -100,9 +106,11 @@ class ModelConverter:
                             break
                     else:
                         continue
-            field = base_fields.get(prop.key) or self.property2field(prop)
+            if not include_relationships and hasattr(prop, "direction"):
+                continue
+            field = base_fields.get(key) or self.property2field(prop)
             if field:
-                result[prop.key] = field
+                result[key] = field
         return result
 
     def fields_for_table(
@@ -118,18 +126,23 @@ class ModelConverter:
         result = dict_cls()
         base_fields = base_fields or {}
         for column in table.columns:
+            key = self._get_field_name(column)
             if self._should_exclude_field(column, fields=fields, exclude=exclude):
                 # Allow marshmallow to validate and exclude the field key.
-                result[column.key] = None
+                result[key] = None
                 continue
             if not include_fk and column.foreign_keys:
                 continue
-            field = base_fields.get(column.key) or self.column2field(column)
+            # Overridden fields are specified relative to key generated by
+            # self._get_key_for_column(...), rather than keys in source model
+            field = base_fields.get(key) or self.column2field(column)
             if field:
-                result[column.key] = field
+                result[key] = field
         return result
 
     def property2field(self, prop, *, instance=True, field_class=None, **kwargs):
+        if hasattr(prop, "_proxied_property"):  # handle synonyms
+            prop = prop._proxied_property
         field_class = field_class or self._get_field_class_for_property(prop)
         if not instance:
             return field_class
@@ -157,6 +170,9 @@ class ModelConverter:
         prop = model.__mapper__.get_property(property_name)
         return self.property2field(prop, **kwargs)
 
+    def _get_field_name(self, prop_or_column):
+        return prop_or_column.key
+
     def _get_field_class_for_column(self, column):
         return self._get_field_class_for_data_type(column.type)
 
@@ -216,6 +232,11 @@ class ModelConverter:
         info = getattr(prop, "info", dict())
         overrides = info.get("marshmallow")
         if overrides is not None:
+            warnings.warn(
+                'Passing `info={"marshmallow": ...}` is deprecated. '
+                "Use `SQLAlchemySchema` and `auto_field` instead.",
+                DeprecationWarning,
+            )
             validate = overrides.pop("validate", [])
             kwargs["validate"] = self._merge_validators(
                 kwargs["validate"], validate
@@ -261,9 +282,10 @@ class ModelConverter:
         kwargs.update({"allow_none": nullable, "required": not nullable})
 
     def _should_exclude_field(self, column, fields=None, exclude=None):
-        if fields and column.key not in fields:
+        key = self._get_field_name(column)
+        if fields and key not in fields:
             return True
-        if exclude and column.key in exclude:
+        if exclude and key in exclude:
             return True
         return False
 
@@ -274,11 +296,12 @@ class ModelConverter:
 default_converter = ModelConverter()
 
 fields_for_model = default_converter.fields_for_model
-"""Generate a dict of field_name: `marshmallow.fields.Field` pairs for the
-given model.
+"""Generate a dict of field_name: `marshmallow.fields.Field` pairs for the given model.
+Note: SynonymProperties are ignored. Use an explicit field if you want to include a synonym.
 
 :param model: The SQLAlchemy model
 :param bool include_fk: Whether to include foreign key fields in the output.
+:param bool include_relationships: Whether to include relationships fields in the output.
 :return: dict of field_name: Field instance pairs
 """
 
